==> argous-1.2.235.tgz: package/lib/components/UtilTextField/UtilTextField.js <==
import { numbersOnly } from '../../utils';
import { TextField } from '@material-ui/core';
import React, { useMemo } from 'react';
import MaskedInput from 'react-maskedinput';


const cepMaskedInput = { inputComponent: (props) => <MaskedInput mask='11111-111' {...props} /> };
const cpfMaskedInput = { inputComponent: (props) => <MaskedInput mask='111.111.111-11' {...props} /> };
const cnpjMaskedInput = { inputComponent: (props) => <MaskedInput mask='11.111.111/1111-11' {...props} /> };
const telephoneMaskedInput = { inputComponent: (props) => <MaskedInput mask='(11) 111111111' {...props} /> };


const UtilTextField = ({ type, onChange, ...props }) => {

  const standard = useMemo(() => {

    let standardObject = { 
      valueHandler: (value) => value, 
      InputProps: {}, 
      label: '' 
    };

    switch (type) {
      case 'cep':
        standardObject.valueHandler = (value) => numbersOnly(value);
        standardObject.InputProps = { ...cepMaskedInput };
        standardObject.label = 'CEP';
        break;
      case 'cpf':
        standardObject.valueHandler = (value) => numbersOnly(value);
        standardObject.InputProps = { ...cpfMaskedInput };
        standardObject.label = 'CPF';
        break;
      case 'cnpj':
        standardObject.valueHandler = (value) => numbersOnly(value);
        standardObject.InputProps = { ...cnpjMaskedInput };
        standardObject.label = 'CNPJ';
        break;
      case 'telephone':
        standardObject.valueHandler = (value) => numbersOnly(value);
        standardObject.InputProps = { ...telephoneMaskedInput };
        standardObject.label = 'TELEFONE';
        break;
      default:
        break;
    }

    return standardObject;
  }, [type]);

  const handleOnChange = (event) => {
    let newValue = event.target.value;
    newValue = standard.valueHandler(newValue);
    onChange(event, newValue);
  };


  return (
    <TextField 
      {...props} 
      label={props?.label || standard.label} 
      InputProps={{ ...standard.InputProps, ...(props?.InputProps || {}) }} 
      onChange={handleOnChange} 
    />
  );
};


export default UtilTextField;

==> argous-1.2.240.tgz: package/lib/components/UtilTextField/UtilTextField.js <==
import { numbersOnly } from '../../utils';
import { TextField } from '@material-ui/core';
import React, { useMemo } from 'react';
import MaskedInput from 'react-maskedinput';


const cepMaskedInput = { inputComponent: (props) => <MaskedInput mask='11111-111' {...props} /> };
const cpfMaskedInput = { inputComponent: (props) => <MaskedInput mask='111.111.111-11' {...props} /> };
const cnpjMaskedInput = { inputComponent: (props) => <MaskedInput mask='11.111.111/1111-11' {...props} /> };
const telephoneMaskedInput = { inputComponent: (props) => <MaskedInput mask='(11) 111111111' {...props} /> };


const UtilTextField = ({ type, onChange, ...props }) => {

  const standard = useMemo(() => {

    let standardObject = { 
      valueHandler: (value) => value, 
      InputProps: {}, 
      label: '' 
    };

    switch (type) {
      case 'cep':
        standardObject.valueHandler = (value) => numbersOnly(value);
        standardObject.InputProps = { ...cepMaskedInput };
        standardObject.label = 'CEP';
        break;
      case 'cpf':
        standardObject.valueHandler = (value) => numbersOnly(value);
        standardObject.InputProps = { ...cpfMaskedInput };
        standardObject.label = 'CPF';
        break;
      case 'cnpj':
        standardObject.valueHandler = (value) => numbersOnly(value);
        standardObject.InputProps = { ...cnpjMaskedInput };
        standardObject.label = 'CNPJ';
        break;
      case 'telephone':
        standardObject.valueHandler = (value) => numbersOnly(value);
        standardObject.InputProps = { ...telephoneMaskedInput };
        standardObject.label = 'TELEFONE';
        break;
      default:
        break;
    }

    return standardObject;
  }, [type]);

  const handleOnChange = (event) => {
    let newValue = event.target.value;
    newValue = standard.valueHandler(newValue);
    onChange(event, newValue);
  };


  return (
    <TextField 
      {...props} 
      label={(props?.label === false) ? '' : (props?.label) ? props?.label : standard.label} 
      InputProps={{ ...standard.InputProps, ...(props?.InputProps || {}) }} 
      onChange={handleOnChange} 
    />
  );
};


export default UtilTextField;
